@@ -12,6 +12,18 @@ package Child3 {
     use base 'Parent';
 };
 
+package Child4 {
+    use base "Parent";
+};
+
+package Child5 {
+    use base q{Parent};
+};
+
+package Child6 {
+    use base qq/Parent/;
+};
+
 package GrandChild {
     use base 'Child';
 };
